aboutsummaryrefslogtreecommitdiffstats
path: root/sdklauncher
diff options
context:
space:
mode:
authorRaphael Moll <ralf@android.com>2010-08-21 18:03:49 -0700
committerRaphael Moll <ralf@android.com>2010-08-23 13:37:40 -0700
commit0913421ffd4ab078bc2f9472c73f1e5bbf9525c4 (patch)
treea84d9b59bce797fe75a785903a580676148761c6 /sdklauncher
parent0ddce47c639201891296b449676baa2705bbfd72 (diff)
downloadsdk-0913421ffd4ab078bc2f9472c73f1e5bbf9525c4.zip
sdk-0913421ffd4ab078bc2f9472c73f1e5bbf9525c4.tar.gz
sdk-0913421ffd4ab078bc2f9472c73f1e5bbf9525c4.tar.bz2
SDK: Rename "SDK Setup.exe" to "SDK Manager.exe"
Change-Id: Id62b59e75e92fe14376353211dd59d89f4ee63c6
Diffstat (limited to 'sdklauncher')
-rw-r--r--sdklauncher/sdklauncher.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sdklauncher/sdklauncher.c b/sdklauncher/sdklauncher.c
index e1d97a1..d3c4445 100644
--- a/sdklauncher/sdklauncher.c
+++ b/sdklauncher/sdklauncher.c
@@ -15,7 +15,7 @@
*/
/*
* The "SDK Launcher" is for Windows only.
* This simple .exe will sit at the root of the Windows SDK
* and currently simply executes tools\android.bat.
* Eventually it should simply replace the batch file.
@@ -65,7 +65,7 @@ void display_error(LPSTR description) {
s2 = (LPSTR) malloc(strlen(description) + strlen(s) + 5);
sprintf(s2, "%s\r\n%s", description, s);
- MessageBox(NULL, s2, "Android SDK Setup - Error", MB_OK);
+ MessageBox(NULL, s2, "Android SDK Manager - Error", MB_OK);
free(s2);
LocalFree(s);
}
@@ -168,7 +168,7 @@ void read_temp_file(LPSTR temp_filename) {
*s2 = 0;
}
- MessageBox(NULL, s1, "Android SDK Setup - Output", MB_OK);
+ MessageBox(NULL, s1, "Android SDK Manager - Output", MB_OK);
}
}
@@ -15,7 +15,7 @@
*/
/*
- * The "SDK Launcher" is for Windows only.
+ * The "SDK Manager" is for Windows only.
* This simple .exe will sit at the root of the Windows SDK
* and currently simply executes tools\android.bat.